Class: Module
- Inherits:
-
Object
- Object
- Module
- Defined in:
- lib/revise/core_ext/module.rb
Instance Method Summary collapse
-
#mattr_accessor(*syms) ⇒ Object
Extends the module object with module and instance accessors for class attributes, just like the native attr* accessors for instance attributes.
- #mattr_reader(*syms) ⇒ Object
- #mattr_writer(*syms) ⇒ Object
Instance Method Details
#mattr_accessor(*syms) ⇒ Object
Extends the module object with module and instance accessors for class attributes, just like the native attr* accessors for instance attributes.
48 49 50 51 |
# File 'lib/revise/core_ext/module.rb', line 48 def mattr_accessor(*syms) mattr_reader(*syms) mattr_writer(*syms) end |
#mattr_reader(*syms) ⇒ Object
4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 |
# File 'lib/revise/core_ext/module.rb', line 4 def mattr_reader(*syms) = syms. syms.each do |sym| raise NameError.new('invalid attribute name') unless sym =~ /^[_A-Za-z]\w*$/ class_eval(" @@\#{sym} = nil unless defined? @@\#{sym}\n\n def self.\#{sym}\n @@\#{sym}\n end\n EOS\n\n unless options[:instance_reader] == false || options[:instance_accessor] == false\n class_eval(<<-EOS, __FILE__, __LINE__ + 1)\n def \#{sym}\n @@\#{sym}\n end\n EOS\n end\n end\nend\n", __FILE__, __LINE__ + 1) |
#mattr_writer(*syms) ⇒ Object
26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/revise/core_ext/module.rb', line 26 def mattr_writer(*syms) = syms. syms.each do |sym| raise NameError.new('invalid attribute name') unless sym =~ /^[_A-Za-z]\w*$/ class_eval(" def self.\#{sym}=(obj)\n @@\#{sym} = obj\n end\n EOS\n\n unless options[:instance_writer] == false || options[:instance_accessor] == false\n class_eval(<<-EOS, __FILE__, __LINE__ + 1)\n def \#{sym}=(obj)\n @@\#{sym} = obj\n end\n EOS\n end\n end\nend\n", __FILE__, __LINE__ + 1) |